function status = sgcallinit(SGWin)
%SGCALLINIT Connect MCS Toolbox to an existing StratiGraph window.
%   Status = SGCALLINIT(SGWin) initialize the connection between the 
%   existing StratiGraph window with WindowID SGWin and MCS Toolbox.
%   SGCALLINIT is only intended to be called from StratiGraph when it is 
%   opened outside of Matlab or when loading the Matlab plug-in.
%
%   See also SGOPEN.

global MCS_PREF

import se.umu.stratigraph.core.util.WindowID;

if ~isa(SGWin,'WindowID')
	status = java.lang.String('SGWin is not a WindowID. SGCALLINIT is probably called outside of StratiGraph.');
	return
end

status = java.lang.String('');

try 
	if ~isfield(MCS_PREF,'sgwin') || isempty(MCS_PREF.sgwin) || isempty(MCS_PREF.sgwin(1).winID)
		% This should normally be the case...
		fprintf('Initializing MCS_PREF\n')
		MCS_PREF.sgwin(1).label = char(SGWin.toString());
		MCS_PREF.sgwin(1).winID = SGWin;
  else
		% Check if the StratiGraph window already is associated with MCS Toolbox
		[b,~] = ismemberwin(SGWin, {MCS_PREF.sgwin(:).winID});
		if b && WindowID.exist(SGWin)
      fprintf('Connecting StratiGraph window %s with MCS Toolbox\n',char(SGWin.toString()))
			return
		else
			fprintf('Adding StratiGraph window %s to MCS Toolbox\n',char(SGWin.toString()))
			MCS_PREF.sgwin(end+1).label = char(SGWin.toString());
			MCS_PREF.sgwin(end).winID = SGWin;
		end
	end
catch e
	% Create and return error message
	status = sgerrormsg(e);
end

end

%%-----------------------
function [b,k] = ismemberwin(id,ids)

b = false;
k = 0;
while ~b && k < length(ids)
  k = k+1;
	if id == ids{k}
		b = true;
	end
end

end
