function sgclose(label)
%SGCLOSE Close a StratiGraph window.
%   SGCLOSE(Label) closes the StratiGraph window with label Label.
%
%   SGCLOSE('all') closes all opened StratiGraph windows. Even those who 
%   are not opened from Matlab.
%
%   See also SGOPEN.

global MCS_PREF

% Close all
if strcmpi(label,'all')
	se.umu.stratigraph.core.util.Application.getApplication().closeAll();
	MCS_PREF.sgwin = struct([]);	
	return
end

if isnumeric(label)
	if isscalar(label)
		label = sprintf('%i',label);
	else
		error(['The ''label'' argument must be either a character, ', ...
		'string, or a positive integer']);
	end
elseif ~ischar(label)
	error(['The ''label'' argument must be either a character, ', ...
	'string, or a positive integer']);
end

openedLabels = sglabels;
if ~strcmpi(label,openedLabels)
  error('No StratiGraph window with label ''%s'' exists.',label)	
else
	sgapp = se.umu.stratigraph.core.util.Application.getApplication();
	appFrame = sgapp.getWindow(label);
	sgapp.closeWindow(appFrame.getId());
	
	% Remove from MCS_PREF	
	tf = ~strcmpi(label,{MCS_PREF.sgwin.label});
	MCS_PREF.sgwin = MCS_PREF.sgwin(tf);
end