function sgset(varargin)
%SGSET Initialize StratiGraph with a new start node.
%   SGSET(StructObj,StrataType) initializes StratiGraph with the canonical
%   structure represented by the object StructObj. The parameter StrataType
%   specifies the strata and must be either 'orbit' or 'bundle'. If
%   StrataType is omitted, 'orbit' is assumed. By default, if there exists
%   a graph in StraiGraph the user will be asked if it should be
%   overwritten.
%
%   SGSET(StructObj,StrataType,ForceOverwrite) let the user supress the
%   prompt if any existing graph in StratiGraph should be overwitten by
%   setting ForceOverwrite to true.
%
%   SGSET(...,Label) specifies the label of the StratiGraph window to be
%   initialize. If no label is provided the initialization is send to the 
%   first window.
%
%   See also SGGET, SGOPEN, SGSETTOLERANCE.

nargoutchk(0,0);
  
global MCS_PREF;
  
label = '';
force = false;
stratatype = 'orbit';
	
if ~isfield(MCS_PREF,'sgwin')
	error(['No instance of StratiGraph is started. Start StratiGraph' ...
	' with ''sgopen''.']);
end

try
	if isobject(varargin{1})
		narginchk(1,4);
		struct = varargin{1};
		if nargin > 1
			stratatype = varargin{2};
			if ~ischar(stratatype) | ~strcmpi(stratatype,{'orbit','bundle'}) %#ok<OR2>
				error('Unknown strata keyword.');
			end
    end
    if nargin > 2
      force = varargin{3};
    end
		if nargin == 4
			label = num2str(varargin{4});
		end
      
		com = sgcom(struct,stratatype);
		remoteData = false;
	else
		error('Illegal first argument.');
	end
catch err
	rethrow(err);
end

% Associate the sgcom object with the sg window
[~,winID,label] = sgwindata(label,com);
	
% Check that MCS Toolbox Integrator is loaded into StratiGraph
import se.umu.stratigraph.core.PluginManager;
if ~PluginManager.isLoaded(winID,'MCS Toolbox Integrator')
	error('MCS:sgset:ExtensionNotLoaded',...
    'StratiGraph extension ''MCS Toolbox Integrator'' is not loaded for window ''%s''.',label)
end

import se.umu.stratigraph.Main;
import se.umu.stratigraph.core.GraphManager;
import se.umu.stratigraph.plugin.extension.mcs.MCSRequestNewGraphContainer;
import se.umu.stratigraph.plugin.extension.mcs.MCSRequest;

[jstr,setupName,setupSize] = tojava(com); % Return a Java structure object
jsm  = jstratmodel(com); % Return Strata
try
  if ~force 
    graph = GraphManager.local(winID);
    if ~isempty(graph) && ~graph.isEmpty()
      a = input('There exists a graph in the StratiGraph window.\nDo you want to replace it with the new structure (Y/n)?','s');
      if strcmpi(a,'n')
        disp('Operation canceled!')
        return
      end
    end
  end
  
	% Call se.umu.stratigraph.plugin.extension.mcs.MCSRequestNewGraphContainer
	jrc  = MCSRequestNewGraphContainer(jstr, jsm, setupName, setupSize, remoteData);
	% Call se.umu.stratigraph.plugin.extension.mcs.MCSRequest
	jre  = MCSRequest(winID, jrc);
    
	% Activate and send the StratiGraph window to front
	Main.setVisible(winID);
		
  % Route the request to the MCS Toolbox extension
	Main.callExtension(jre);
catch err
	error('MCS:sgset:SetData','No response or StratiGraph returned an error.');
end
	